@@ -98,7 +98,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
     """
     模式 = str(模式)
     if 模式 == "1":
-        a = 强制类型检测(数据, 'dict')
+        a = 强制类型检测(数据, ['dict'])
         if a:
                 数据 = str(数据)
                 数据 = bytes(数据, encoding="utf-8")
@@ -151,7 +151,7 @@ def 缓存(模式, 数据: dict = None, 文件名="Fishconsole.fcc",变量名=No
             except NameError:
                 logs.变量查看("解密", 解密)
                 logs.安全退出("缓存》模式3》变量名提取》操作失败【目标被非法篡改】")
-            if 强制类型检测(数据,"dict"):
+            if 强制类型检测(数据,["dict"]):
                 解密=dict(解密,**数据)
                 数据 = str(解密)
                 数据 = bytes(数据, encoding="utf-8")
