@@ -42,7 +42,7 @@ def 帮助():
     if True:
         a=(
             "后台的占用怎么这么大？\n"
-            "启动时就是这样，但是python有自己的内存回收机制，我们只需等待它慢慢回收即可（我懒得手动释放反正大家内存都8个G起步）\n"
+            "启动时就是这样，但是python有自己的内存回收机制，我们只需等待它慢慢回收即可（我懒得手动释放反正大家内存都8个G起步）\n\n"
             "我如何重新进入？\n"
             "导入helps包，然后键入helps.帮助()就可以回来了\n\n"
             "关于控制台输出模块的帮助文档会显示在命令行中，选中你想查看的内容，我们将会提供相应的窗口。\n\n"
